@@ -863,7 +863,7 @@ END
 Uncorrectable error.  If confused, consult administrator.
 END
       : !length $override_status ? __ <<END
-Could perhaps be forced using --deliberately.  Consult documentation.
+Could perhaps be forced using --deliberately-<something>.  See dgit(1).
 END
       : f_ <<END, $override_status;
 Forcing due to %s
